pub struct AssetRequest {
pub asset_type: String,
pub args: Option<Value>,
}Expand description
Incoming request to construct an asset from an external caller
Fields
asset_type: Stringtype name as it appears in the world declaration (“Mesh”, “Material”, …) case-insensitive; underscores ignored
args: Option<Value>constructor args. If None, the type’s default_args are used